summaryrefslogtreecommitdiffstats
path: root/src/com/android/launcher3/DropTarget.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/com/android/launcher3/DropTarget.java')
-rw-r--r--src/com/android/launcher3/DropTarget.java5
1 files changed, 4 insertions, 1 deletions
diff --git a/src/com/android/launcher3/DropTarget.java b/src/com/android/launcher3/DropTarget.java
index 90b8f1c75..efdeb1fa3 100644
--- a/src/com/android/launcher3/DropTarget.java
+++ b/src/com/android/launcher3/DropTarget.java
@@ -48,9 +48,12 @@ public interface DropTarget {
/** The view that moves around while you drag. */
public DragView dragView = null;
/** The data associated with the object being dragged */
public ItemInfo dragInfo = null;
+ /** The data associated with the object being dragged */
+ public ItemInfo originalDragInfo = null;
+
/** Where the drag originated */
public DragSource dragSource = null;
@@ -48,9 +48,12 @@ public interface DropTarget {
/** The view that moves around while you drag. */
public DragView dragView = null;
- /** The data associated with the object being dragged */
+ /** The data associated with the object, after item is dropped. */
public ItemInfo dragInfo = null;